import * as react from 'react';

type HighlightHeadingProps = {
    /**
     * The title used in the heading of the component.
     */
    title: string;
    /**
     * The decorative image used next to the heading.
     */
    decorativeImageSrc?: string;
    /**
     * Set the heading level in the component's heading.
     * @default 'h2'
     */
    headingLevel?: 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6';
    /**
     * The background image used in the component.
     */
    backgroundImageSrc: string;
    /**
     * The custom image element to be used instead of the default img tag.
     * @example
     * <HighlightHeading customLink={NextImage} />
     */
    customImage?: any;
    /**
     * The custom props to be passed to the custom image element.
     * @example
     * <HighlightHeading customLink={NextImage} customImageProps={{ layout: 'fill' }} />
     */
    customImageProps?: any;
};
/**
 * A heading with a background image and a possible decorative image.
 */
declare const HighlightHeading: react.ForwardRefExoticComponent<HighlightHeadingProps & react.RefAttributes<HTMLDivElement>>;

export { HighlightHeading, HighlightHeadingProps };
